Welcome to PyNMR-STAR!
======================================

A Python module for reading, writing, and manipulating NMR-STAR files.
|License| |Wheel| |PythonVersions|

Previous python versions (back to 2.6) are supported by the v2 branch
(version 2.x releases on PyPI).

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage/nmrstar-introduction
   usage/quick-start
   usage/examples
   usage/full
   usage/unit-test
   release-notes


Overview
--------

This library was developed by the BMRB to give the Python-using NMR
community tools to work with the NMR-STAR data format. It is used
internally and is actively maintained. The library is thoroughly
documented such that calling ``help(object_or_method)`` from an
interactive python session will print the documentation for the object
or method.

There are several command-line based tools developed to enable simple
queries to pull data out of an NMR-STAR file. Those tools also serve as
great examples of how to use the library. You can view those
`here <https://github.com/uwbmrb/PyNMRSTAR/tree/v3/cmdline>`__.

For more examples of PyNMRSTAR library usage, please head to
:doc:`usage/examples`. For the full documentation of all
available methods and classes, please look at :doc:`usage/full`.

For any questions or suggestions, please create an issue on the
`GitHub page <https://github.com/uwbmrb/PyNMRSTAR/>`__.


.. |BuildStatus| image:: https://travis-ci.org/uwbmrb/PyNMRSTAR.svg?branch=v3
   :target: https://travis-ci.org/uwbmrb/PyNMRSTAR

.. |PythonVersions| image:: https://img.shields.io/pypi/pyversions/pynmrstar.svg
   :target: https://pypi.org/project/PyNMRSTAR

.. |License| image:: https://img.shields.io/pypi/l/pynmrstar.svg
   :target: https://pypi.org/project/PyNMRSTAR

.. |Wheel| image:: https://img.shields.io/pypi/wheel/pynmrstar.svg
   :target: https://pypi.org/project/PyNMRSTAR



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
